@@ -1,7 +1,8 @@
 import base64
 import logging
 
-from python_sdk_client.clients_enum import EnvType
+from plotrisk_python_client.util import EnvType
+
 from python_sdk_client.cropin_api import CropinAPI
 
 """Example on how to use CropAPI.  
